#
# spec file for package desktopfolder
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           desktopfolder
Version:        1.1.2
Release:        lp152.1.4
Summary:        Tool for organizing the desktop with panels, notes and photos
License:        GPL-3.0-or-later
Group:          System/GUI/Other
URL:            https://github.com/spheras/desktopfolder/
Source:         https://github.com/spheras/desktopfolder/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  meson >= 0.40.0
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  vala
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22
BuildRequires:  pkgconfig(gtksourceview-3.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libwnck-3.0)
Recommends:     %{name}-lang

%description
A program with which the desktop can be organized with panels that hold things.
  * Access files, folders and apps from your desktop
  * Drop files, folders, links and .desktop launchers inside panels
  * Resize, position and color panels
  * Display photos and keep notes on your desktop
  * Reveal the desktop with ⌘-D (Command-D)

%lang_package

%prep
%setup -q

%build
%meson
%meson_build

%install
%meson_install

# https://github.com/spheras/desktopfolder/issues/69
find %{buildroot} -name \*.??g -exec chmod 0644 {} \;

%{suse_update_desktop_file -r \
  %{buildroot}%{_datadir}/applications/com.github.spheras.desktopfolder.desktop GTK Utility DesktopSettings}
%find_lang com.github.spheras.desktopfolder %{name}.lang
%fdupes %{buildroot}/%{_datadir}

# Add OnlyShowIn key
if ! grep OnlyShowIn.*Pantheon %{buildroot}%{_sysconfdir}/xdg/autostart/com.github.spheras.desktopfolder-autostart.desktop; then
	sed -i '$aOnlyShowIn=Pantheon;' %{buildroot}%{_sysconfdir}/xdg/autostart/com.github.spheras.desktopfolder-autostart.desktop
else
	'This entry already exists' 2> /dev/null
fi
#

%files
%license LICENSE*
%doc AUTHORS* README.md
%{_bindir}/com.github.spheras.desktopfolder
%{_datadir}/applications/com.github.spheras.desktopfolder.desktop
%{_datadir}/glib-2.0/schemas/com.github.spheras.desktopfolder.gschema.xml
%{_datadir}/icons/hicolor/*/apps/com.github.spheras.desktopfolder.??g
%{_datadir}/metainfo/com.github.spheras.desktopfolder.appdata.xml
%{_sysconfdir}/xdg/autostart/com.github.spheras.desktopfolder-autostart.desktop

%files lang -f %{name}.lang

%changelog
* Mon Jan 13 2020 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.1.2:
  * Merge pull request #281 from JoshStrobl/vala_compilation_fix
  * Merge pull request #279 from UbuntuBudgie/itemviewcleanup
  * Merge pull request #278 from UbuntuBudgie/photoopen
  * Fix compilation against Vala 0.46
  * Remove unnecessary separators from note menu
  * Remove unneeded window parent from menuitemcolor
  * Fix crash due to null parent window
  * Fix padding for color menu item to be consistent with other
    menu items
  * Make FolderWindow menu consistent with other submenus
  * Remove unnecessary separate for photo menu
  * Recombine panel properties menu options
  * Reorganise menu to combine actions
  * Add double click on photo to open in default viewer #277
  * Add popup option to open photo in default viewer
  * Merge pull request #274 from UbuntuBudgie/autostart
  * Let GSD handle starting/not starting desktopfolder via
    autostart
  * Merge branch 'master' of
    https://github.com/spheras/desktopfolder
  * close #272
  * Update fr.po
  * Merge pull request #259 from UbuntuBudgie/vala44
  * Fix compilation issues with vala 0.44
- Drop desktopfolder-1.1.1-vala-0.44.patch
- Drop desktopfolder-1.1.1-vala-0.46.patch
* Wed Oct 30 2019 Alexei Podvalsky <avvissu@yandex.by>
- Add desktopfolder-1.1.1-vala-0.46.patch
* Wed Aug  7 2019 Alexei Podvalsky <avvissu@yandex.by>
- Add OnlyShowIn=Pantheon to *.autostart.desktop
* Sun May 12 2019 Alexei Podvalsky <avvissu@yandex.by>
- Add desktopfolder-1.1.1-vala-0.44.patch
* Mon Mar 11 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.1.1:
  * appdata updated
* Mon Feb 18 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.1.0:
  * header custom style bugfix
  * removing debug lines
  * folder search bugfixing
  * dragdrop optimization
  * minor right window resize bugfixing
  * close issue #250
  * close issue #244
  * issue #211, improved desktop panel position taking into
    account docks like plank
  * first version of multiselection, reference #118 issue
  * fix issue #240 check whether the item could be executable or not
  * possible solution to issue #238
  * show loading outside thread
  * delete key to remove panels commented (I feel it is too
    drastic)
  * Merge pull request #235 from lvitals/fix_new_folder
  * Fix problem by creating new folders
  * Give travis intltool to chew on
- Spec file cleanup
* Sun Nov 11 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.0.10:
  * Removed first folder setting. Not needed due to desktop panel
    condition. #121
  * issue #136, allow change icon for everything
  * Merge pull request #137 from UbuntuBudgie/svg
  * Full path icon display and SVG choose icon support #135
  * moving debian to deb-packaging branch
  * uncrustifying
  * Fix typos that check-all-the-things reported
  * Resolve appstreamcli validate issues
  * menu item color right space
  * issue #131 - magic numbers
  * Allow desktop configuration apps to stop showing
    desktopfolder #126
  * updated to Gtk+3.22, replacing old deprecated methods
  * close #123 open wallpaper settings for pantheon and gnome
    derivatives
  * removed deprecated gtk functions <3.12
  * adjusting note title label margins
  * Ensure all source files have an up-to-date copyright statement
* Mon Oct 22 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in descriptions.
* Tue Oct 16 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.0.9:
  * minor bugfixing
* Mon Oct  8 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.0.7:
  * Change Wallpaper from Desktop right click
  * Dutch Translation by @Vistaus
  * Improved Russian Translation by @ingumsky
  * Updated project for GTK 3.22 and Elementary Juno
  * Minor Bugfixing
* Fri Mar  2 2018 avvissu@yandex.by
- Update to 1.0.6:
  * version parameter
  * custom desktop folder name
  * changes:~ files ignored improved saving performance
  * italian language
* Sat Jan  6 2018 avvissu@yandex.by
- Update to 1.0.5:
  * fake desktop update status automatically bugfixing
  * existent setting property bugfixing
  * fake desktop removed when property changed
  * note back and top bugfixing
  * Note rename popup bugfixing
  * issue #90 - Drag & drop breaks after dragging & dropping an
    item between panels
  * Update lt.po
  * properties dialog modal #87 lock panel -header bugfix
  * improved notes and photos json modifications
  * Add libjson-glib-dev to dependency list in README
  * updated authors and changelog
* Tue Nov  7 2017 avvissu@yandex.by
- Initial package
